==> haskell-hls-retrie-plugin-2.0.0.0-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-retrie-plugin-2.0.0.0-Oqt7R2MAjF2dyK2vLlVqV
key:                  hls-retrie-plugin-2.0.0.0-Oqt7R2MAjF2dyK2vLlVqV
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2ffe670566e79d4af0e2ede351490112
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.0.0.0-Oqt7R2MAjF2dyK2vLlVqV
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-9.4.8
    ghcide-2.0.0.0-Kl07NIqTBw1IxudqWSN9d0
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-plugin-api-2.0.0.0-CjPH3i9n95sAzh7VU9zzvQ
    hls-refactor-plugin-2.0.0.0-Z38ci4gGOW3q0Y2ga4r1D
    lsp-1.6.0.0-EzZWHSTgh2eBqXWsr3rUZN
    lsp-types-1.6.0.1-H2fJZN43yMpAmyISbT7lDk
    retrie-1.2.3-5jlnROgkvF672M2d8EuQVd
    safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-retrie-plugin-2.0.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-retrie-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-retrie-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-retrie-plugin-2.0.0.0-IyvYx1l7KVxHQGtD1HFTvp
key:                  hls-retrie-plugin-2.0.0.0-IyvYx1l7KVxHQGtD1HFTvp
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Retrie integration plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a61c3b996b4cb9cb6cf8f0508b43fe26
exposed:              True
exposed-modules:      Ide.Plugin.Retrie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-retrie-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-retrie-plugin
hs-libraries:         HShls-retrie-plugin-2.0.0.0-IyvYx1l7KVxHQGtD1HFTvp
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-9.4.8
    ghcide-2.0.0.0-2OoOssIvpRZJ70cxoplPUd
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-plugin-api-2.0.0.0-CjPH3i9n95sAzh7VU9zzvQ
    hls-refactor-plugin-2.0.0.0-5N95yui497bIwKfbmZZ74R
    lsp-1.6.0.0-EzZWHSTgh2eBqXWsr3rUZN
    lsp-types-1.6.0.1-H2fJZN43yMpAmyISbT7lDk
    retrie-1.2.3-5jlnROgkvF672M2d8EuQVd
    safe-exceptions-0.1.7.4-ES7S1HwS0lOI4lBBxEPT7M stm-2.5.1.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-retrie-plugin/html/hls-retrie-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-retrie-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
